@@ -2,7 +2,7 @@
     Flowblade Movie Editor is a nonlinear video editor.
     Copyright 2014 Janne Liljeblad.
 
-    This file is part of Flowblade Movie Editor <http://code.google.com/p/flowblade>.
+    This file is part of Flowblade Movie Editor <https://github.com/jliljebl/flowblade/>.
 
     Flowblade Movie Editor is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -23,6 +23,7 @@ This module contains complex property editors.
 """
 
 import math
+import webbrowser
 
 from gi.repository import Gtk
 
@@ -729,11 +730,6 @@ class BoxEditor:
     def draw_box(self, cr, allocation):
         x, y, w, h = allocation
 
-        if editorpersistance.prefs.theme == appconsts.LIGHT_THEME:
-            cr.set_source_rgb(*BOX_BG_COLOR )
-            cr.rectangle(0, 0, self.pix_size + 1, self.pix_size + 1)
-            cr.fill()
-
         # value lines
         cr.set_source_rgb(*BOX_LINE_COLOR)
         step = self.pix_size / 8
@@ -883,10 +879,9 @@ class CurvesBoxEditor(BoxEditor):
         self.last_point = None
         self.edit_on = False
 
-        if editorpersistance.prefs.theme != appconsts.LIGHT_THEME:
-            BOX_LINE_COLOR = (0.8, 0.8, 0.8)
-            CURVE_COLOR = (0.8, 0.8, 0.8)
-            self.curve_color = CURVE_COLOR
+        BOX_LINE_COLOR = (0.8, 0.8, 0.8)
+        CURVE_COLOR = (0.8, 0.8, 0.8)
+        self.curve_color = CURVE_COLOR
 
     def set_curve(self, curve, curve_color):
         self.curve = curve
@@ -1094,208 +1089,6 @@ class ColorGrader:
             self.hs_label.set_text(sat_str)
 
 
-"""
-# NON_ MLT PROPERTY SLIDER DEMO CODE
-def hue_changed(self, ep, value):
-    ep.write_property_value(str(value))
-    self.update_properties()
-
-def saturation_changed(self, ep, value):
-    ep.write_property_value(str(value))
-    self.update_properties()
-
-def value_changed(self, ep, value):
-    ep.write_property_value(str(value))
-    self.update_properties()
-"""
-
-"""
-class AbstractColorWheel:
-
-    def __init__(self, edit_listener):
-        self.widget = cairoarea.CairoDrawableArea2( 260,
-                                                    260,
-                                                    self._draw)
-        self.widget.press_func = self._press_event
-        self.widget.motion_notify_func = self._motion_notify_event
-        self.widget.release_func = self._release_event
-        self.X_PAD = 3
-        self.Y_PAD = 3
-        self.CENTER_X = 130
-        self.CENTER_Y = 130
-        self.MAX_DIST = 123
-        self.twelwe_p = (self.CENTER_X , self.CENTER_Y - self.MAX_DIST)
-        self.CIRCLE_HALF = 6
-        self.cursor_x = self.CENTER_X
-        self.cursor_y = self.CENTER_Y
-        self.WHEEL_IMG = GdkPixbuf.Pixbuf.new_from_file(respaths.IMAGE_PATH + "color_wheel.png")
-        self.edit_listener = edit_listener
-        self.angle = 0.0
-        self.distance = 0.0
-
-    def _press_event(self, event):
-
-        self.cursor_x, self.cursor_y = self._get_legal_point(event.x, event.y)
-        self._save_point()
-        self.widget.queue_draw()
-
-    def _motion_notify_event(self, x, y, state):
-
-        self.cursor_x, self.cursor_y = self._get_legal_point(x, y)
-        self._save_point()
-        self.widget.queue_draw()
-
-    def _release_event(self, event):
-        self.cursor_x, self.cursor_y = self._get_legal_point(event.x, event.y)
-        self._save_point()
-        self.edit_listener()
-        self.widget.queue_draw()
-
-    def _get_legal_point(self, x, y):
-        vec = viewgeom.get_vec_for_points((self.CENTER_X, self.CENTER_Y), (x, y))
-        dist = vec.get_length()
-        if dist < self.MAX_DIST:
-            return (x, y)
-
-        new_vec = vec.get_multiplied_vec(self.MAX_DIST / dist )
-        return new_vec.end_point
-
-    def get_angle(self, p):
-        angle = viewgeom.get_angle_in_deg(self.twelwe_p, (self.CENTER_X, self.CENTER_Y), p)
-        clockwise = viewgeom.points_clockwise(self.twelwe_p, (self.CENTER_X, self.CENTER_Y), p)
-
-        if clockwise:
-             angle = 360.0 - angle;
-
-        # Color circle starts from 11 o'clock
-        angle = angle - 30.0
-        if angle  < 0.0:
-            angle = angle + 360.0
-
-        return angle
-
-    def get_distance(self, p):
-        vec = viewgeom.get_vec_for_points((self.CENTER_X, self.CENTER_Y), p)
-        dist = vec.get_length()
-        return dist/self.MAX_DIST
-
-    def _save_point(self):
-        print "_save_point not implemented"
-        pass
-
-    def get_angle_and_distance(self):
-        if self.band == SHADOW:
-            x = self.shadow_x
-            y = self.shadow_y
-        elif self.band == MID:
-            x = self.mid_x
-            y = self.mid_y
-        else:
-            x = self.hi_x
-            y = self.hi_y
-        p = (x, y)
-        angle = self._get_angle(p)
-        distance = self._get_distance(p)
-        return (angle, distance)
-
-    def _draw(self, event, cr, allocation):
-        x, y, w, h = allocation
-
-        # Draw bg
-        cr.set_source_rgb(*(gui.bg_color_tuple))
-        cr.rectangle(0, 0, w, h)
-        cr.fill()
-
-        cr.set_source_pixbuf(self.WHEEL_IMG, self.X_PAD, self.Y_PAD)
-        cr.paint()
-
-
-class SimpleColorWheel(AbstractColorWheel):
-
-    def __init__(self, edit_listener):
-        AbstractColorWheel.__init__(self, edit_listener)
-        self.value_x = self.cursor_x
-        self.value_y = self.cursor_y
-
-    def _save_point(self):
-        self.value_x = self.cursor_x
-        self.value_y = self.cursor_y
-
-    def get_angle_and_distance(self):
-        p = (self.value_x, self.value_y)
-        angle = self.get_angle(p)
-        distance = self.get_distance(p)
-        return (angle, distance)
-
-    def _draw(self, event, cr, allocation):
-        AbstractColorWheel._draw(self, event, cr, allocation)
-
-        _draw_select_circle(cr, self.cursor_x - self.CIRCLE_HALF, self.cursor_y - self.CIRCLE_HALF, (1,1,1), ACTIVE_RING_COLOR)
-
-
-class SMHColorWheel(AbstractColorWheel):
-
-    def __init__(self, edit_listener):
-        AbstractColorWheel.__init__(self, edit_listener)
-        self.band = SHADOW
-        self.shadow_x = self.cursor_x
-        self.shadow_y = self.cursor_y
-        self.mid_x = self.cursor_x
-        self.mid_y = self.cursor_y
-        self.hi_x = self.cursor_x
-        self.hi_y = self.cursor_y
-
-    def set_band(self, band):
-        self.band = band
-        if self.band == SHADOW:
-            self.cursor_x = self.shadow_x
-            self.cursor_y = self.shadow_y
-        elif self.band == MID:
-            self.cursor_x = self.mid_x
-            self.cursor_y = self.mid_y
-        else:
-            self.cursor_x = self.hi_x
-            self.cursor_y = self.hi_y
-
-    def _save_point(self):
-        if self.band == SHADOW:
-            self.shadow_x = self.cursor_x
-            self.shadow_y = self.cursor_y
-        elif self.band == MID:
-            self.mid_x = self.cursor_x
-            self.mid_y = self.cursor_y
-        else:
-            self.hi_x = self.cursor_x
-            self.hi_y = self.cursor_y
-
-    def get_angle_and_distance(self):
-        if self.band == SHADOW:
-            x = self.shadow_x
-            y = self.shadow_y
-        elif self.band == MID:
-            x = self.mid_x
-            y = self.mid_y
-        else:
-            x = self.hi_x
-            y = self.hi_y
-        p = (x, y)
-        angle = self.get_angle(p)
-        distance = self.get_distance(p)
-        return (angle, distance)
-
-    def _draw(self, event, cr, allocation):
-        AbstractColorWheel._draw(self, event, cr, allocation)
-
-        if self.band == SHADOW:
-            band_color = ACTIVE_SHADOW_COLOR
-        elif self.band == MID:
-            band_color = ACTIVE_MID_COLOR
-        else:
-            band_color = ACTIVE_HI_COLOR
-
-        _draw_select_circle(cr, self.cursor_x - self.CIRCLE_HALF, self.cursor_y - self.CIRCLE_HALF, band_color, ACTIVE_RING_COLOR)
-"""
-
 class ColorBandSelector:
     def __init__(self):
         self.band = SHADOW
@@ -1363,3 +1156,16 @@ class ColorBandSelector:
         cr.close_path()
         cr.fill()
 
+
+class InfoAndTipsEditor:
+    
+        def __init__(self, uri, link_text):
+            self.uri = uri
+            self.widget = Gtk.LinkButton.new_with_label(uri, link_text)
+            self.widget.connect("activate-link", self._open_info)
+            self.widget.set_margin_top(24)
+            self.widget.set_margin_bottom(4)
+
+        def _open_info(self, widget):
+            webbrowser.open(self.uri)
+            return True
