@@ -2,7 +2,7 @@
     Flowblade Movie Editor is a nonlinear video editor.
     Copyright 2012 Janne Liljeblad.
 
-    This file is part of Flowblade Movie Editor <http://code.google.com/p/flowblade>.
+    This file is part of Flowblade Movie Editor <https://github.com/jliljebl/flowblade/>.
 
     Flowblade Movie Editor is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -48,6 +48,7 @@ FADE_OUT_REPLAMENT = "fade_out_replament"                   # replace with fade
 FADE_IN_OUT_REPLAMENT = "fade_in_out_replament"             # replace with fade in and out keyframes
 WIPE_IN_REPLAMENT = "wipe_in_replament"
 
+
 # ------------------------------------------- parse funcs
 def node_list_to_properties_array(node_list):
     """
@@ -98,6 +99,17 @@ def node_list_to_extraeditors_array(node_list):
         editors.append(e_name)
     return editors
 
+def node_list_to_extraeditors_args_dict(node_list):
+    args_dict = {}
+    for node in node_list:
+        e_name = node.getAttribute(NAME)
+        args = node.getAttribute(ARGS)
+        if args == "":
+            args = None
+        args_dict[e_name] = args
+
+    return args_dict
+
 def args_string_to_args_dict(args_str):
     """
     Returns key->value dict of property args.
@@ -109,20 +121,34 @@ def args_string_to_args_dict(args_str):
         args_dict[sides[0]] = sides[1]
     return args_dict
 
+
+# ------------------------------------------- key word replace functions
 def replace_value_keywords(properties, profile):
     """
     Property value expressions may have keywords in default values that 
-    need to be replaced with other expressions when containing
+    need to be replaced with other expressions or int values when containing
     objects first become active.
     """
     sreensize_expr = str(profile.width()) + "x" + str(profile.height())
     sreensize_expr_2 = str(profile.width()) + " " + str(profile.height())
+    sreensize_width = str(profile.width())
+    sreensize_height = str(profile.height())
     for i in range(0, len(properties)):
         name, value, prop_type = properties[i]
         if prop_type == PROP_EXPRESSION:
-            value = value.replace(SCREENSIZE, sreensize_expr)
-            value = value.replace(SCREENSIZE2, sreensize_expr_2)
-            value = value.replace(WIPE_PATH, respaths.WIPE_RESOURCES_PATH)
+            if SCREENSIZE_WIDTH in value:
+                value = value.replace(SCREENSIZE_WIDTH, sreensize_width)
+                prop_type = 0 # value is int after replace
+            elif SCREENSIZE_HEIGHT in value:
+                value = value.replace(SCREENSIZE_HEIGHT, sreensize_height)
+                prop_type = 0 # value is int after replace
+            elif SCREENSIZE in value:
+                value = value.replace(SCREENSIZE, sreensize_expr)
+            elif SCREENSIZE2 in value:
+                value = value.replace(SCREENSIZE2, sreensize_expr_2)
+            elif WIPE_PATH in value:
+                value = value.replace(WIPE_PATH, respaths.WIPE_RESOURCES_PATH)
+
             properties[i] = (name, value, prop_type)
 
 def replace_values_using_clip_data(properties, info, clip):
@@ -319,11 +345,11 @@ def rect_keyframes_value_string_to_geom_kf_array(keyframes_str, out_to_in_func):
     return new_keyframes
     
 def rotating_geom_keyframes_value_string_to_geom_kf_array(keyframes_str, out_to_in_func):
-    # THIS WAS CREATED FOR frei0r cairoaffineblend FILTER. That filter has to use a very particular paramter values
+    # THIS WAS CREATED FOR frei0r cairoaffineblend FILTER. That filter has to use a very particular parameter values
     # scheme to satisty the frei0r requirement of all float values being in range 0.0 - 1.0.
     #
     # Parse extraeditor value properties value string into (frame, [x, y, x_scale, y_scale, rotation], opacity)
-    # keyframe tuples.
+    # keyframe tuples used by keyframeeditorcanvas.RotatingEditCanvas editor.
     new_keyframes = []
     screen_width = current_sequence().profile.width()
     screen_height = current_sequence().profile.height()
@@ -357,30 +383,46 @@ def rotating_geom_keyframes_value_string_to_geom_kf_array(keyframes_str, out_to_
 
     return new_keyframes
 
-def non_freior_rotating_geom_keyframes_value_string_to_geom_kf_array(keyframes_str, out_to_in_func):
-    # Parse extraeditor value properties value string into (frame, [x, y, x_scale, y_scale, rotation], opacity)
-    # keyframe tuples.
+def filter_rotating_geom_keyframes_value_string_to_geom_kf_array(keyframes_str, out_to_in_func):
+    screen_width = current_sequence().profile.width()
+    screen_height = current_sequence().profile.height()
+    
     new_keyframes = []
+
     keyframes_str = keyframes_str.strip('"') # expression have sometimes quotes that need to go away
     kf_tokens =  keyframes_str.split(';')
     for token in kf_tokens:
-        sides = token.split('=')
-        values = sides[1].split(':')
-        frame = int(sides[0])
-        # get values and convert "frei0r.cairoaffineblend" values to editor values
-        # this because all frei0r plugins require values in range 0 - 1
-        x = float(values[0])
-        y = float(values[1])
-        x_scale = float(values[2])
-        y_scale = float(values[3])
-        rotation = float(values[4])
-        opacity = float(values[5]) * 100
-        source_rect = [x,y,x_scale,y_scale,rotation]
-        add_kf = (frame, source_rect, float(opacity))
-        new_keyframes.append(add_kf)
+        frame, value, kf_type = get_token_frame_value_type(token)
+        values = value.split(':')
 
+        # keyframecanvas.RotatingEditCanvas editor uses x scale and y scale with normalized values,
+        # whereas "affine.transition.rect" uses source image width and height.
+        x_scale = float(values[2]) / float(screen_width)
+        y_scale = float(values[3]) / float(screen_height)
+
+        # keyframecanvas.RotatingEditCanvas editor considers x anf y values position of
+        # anchor point around whicth image is rotated.
+        #
+        # MLT porprty "affine.transition.rect" considers x anf y values amount translation
+        # and rotate image automatically around its tramslated center point.
+        #
+        # So the we need to add half of width and height to mlt values AND 
+        # addional linear correction based on applied scaling when creating
+        # keyframes for keyframecanvas.RotatingEditCanvas editor.
+        x = float(values[0]) + float(screen_width) / 2.0 + \
+            ((x_scale * screen_width) - screen_width) / 2.0
+        y = float(values[1]) + float(screen_height) / 2.0 + \
+            ((y_scale * screen_height) - screen_height) / 2.0
+
+        rotation = float(values[4]) # degrees al arund
+        opacity = 100 # not edited
+
+        source_rect = [x,y,x_scale,y_scale,rotation]
+        add_kf = (int(frame), source_rect, float(opacity), kf_type)
+        new_keyframes.append(add_kf)
+        
     return new_keyframes
-    
+
 def rotomask_json_value_string_to_kf_array(keyframes_str, out_to_in_func):
     new_keyframes = []
     json_obj = json.loads(keyframes_str)
@@ -391,6 +433,20 @@ def rotomask_json_value_string_to_kf_array(keyframes_str, out_to_in_func):
 
     return sorted(new_keyframes, key=lambda kf_tuple: kf_tuple[0]) 
 
+def get_token_frame_value_type(token):
+    sides = token.split(appconsts.KEYFRAME_DISCRETE_EQUALS_STR)
+    if len(sides) == 2:
+        kf_type = appconsts.KEYFRAME_DISCRETE
+    else:
+        sides = token.split(appconsts.KEYFRAME_SMOOTH_EQUALS_STR)
+        if len(sides) == 2:
+            kf_type = appconsts.KEYFRAME_SMOOTH
+        else:
+            sides = token.split(appconsts.KEYFRAME_LINEAR_EQUALS_STR)
+            kf_type = appconsts.KEYFRAME_LINEAR
+                
+    # returns (frame, value, kf_type)
+    return(sides[0], sides[1], kf_type)
 
 # ----------------------------------------------------------------------------- AFFINE BLEND
 def _get_roto_geom_frame_value(token):
@@ -424,7 +480,7 @@ def rotating_ge_write_out_keyframes(ep, keyframes):
     y_scale_val = ""
     rotation_val = ""
     opacity_val = ""
-    
+
     for kf in keyframes:
         frame, transf, opacity, kf_type = kf
         x, y, x_scale, y_scale, rotation = transf
@@ -476,7 +532,7 @@ def rotating_ge_update_prop_value(ep):
         value += frame_str + ";"
 
     ep.value = value.strip(";")
-
+         
 def _get_pixel_pos_from_frei0r_cairo_pos(value, screen_dim):
     # convert positions from range used by frei0r cairo plugins to pixel values
     return -2.0 * screen_dim + value * 5.0 * screen_dim
