@@ -2,7 +2,7 @@
     Flowblade Movie Editor is a nonlinear video editor.
     Copyright 2014 Janne Liljeblad.
 
-    This file is part of Flowblade Movie Editor <http://code.google.com/p/flowblade>.
+    This file is part of Flowblade Movie Editor <https://github.com/jliljebl/flowblade/>.
 
     Flowblade Movie Editor is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -46,6 +46,7 @@ import dialogutils
 import glassbuttons
 import gui
 import guicomponents
+import guipopover
 import guiutils
 import edit
 import editevent
@@ -114,7 +115,7 @@ def _current_tline_frame():
     return editorstate.current_tline_frame()
 
 # ---------------------------------- edit button events
-def cut_pressed():
+def cut_pressed(use_as_action_build_func=False):
     if not timeline_visible():
         updater.display_sequence_in_monitor()   
 
@@ -141,7 +142,7 @@ def cut_pressed():
         index = track.get_clip_index_at(int(tline_frame))
         try:
             clip = track.clips[index]            
-            # don't cut blanck clips
+            # don't cut blank clips
             if clip.is_blanck_clip:
                 continue
         except Exception:
@@ -161,7 +162,10 @@ def cut_pressed():
                 "clip":clip,
                 "clip_cut_frame":clip_frame}
         action = edit.cut_action(data)
-        action.do_edit()
+        if use_as_action_build_func == True:
+            return action
+        else:
+            action.do_edit()
    
     updater.repaint_tline()
 
@@ -322,7 +326,7 @@ def _collect_compositors_for_split(playhead):
     # first: the compositor lies completely before the playhead position
     # we do not have to deal with those and leave them untouched
     # compositor.clip_out < playhead position
-    # second: the compositor lies completly behind the playhead position
+    # second: the compositor lies completely behind the playhead position
     # the compositor needs to be removed from the split sequence and needs to
     # be moved to the newly created one. we need to create a duplicate and modify
     # its clip_in and clip_out properties. basically this formula should apply:
@@ -360,7 +364,7 @@ def _collect_compositors_for_split(playhead):
         new_compositors.append(new_compositor)
     
     # done with collecting all new necessary compositors
-    # now we remove the compositors that are completly after playhead positions
+    # now we remove the compositors that are completely after playhead positions
     # cut compositors have already been reduces in length
     for index in range(0, len(compositors_to_remove)):
         old_compositor = compositors_to_remove[index]
@@ -402,7 +406,7 @@ def splice_out_button_pressed():
 
     # A single clip delete can trigger a special clip cover delete
     # See if such delete should be attempted.
-    # Exit if done succesfully, do normal splice out and report if failed
+    # Exit if done successfully, do normal splice out and report if failed
     cover_delete_failed = False
     if editorpersistance.prefs.trans_cover_delete == True:
         if movemodes.selected_range_out == movemodes.selected_range_in:
@@ -508,7 +512,7 @@ def lift_button_pressed():
     if movemodes.selected_track == -1:
         return
 
-    # Edit consumes selection, set clips seletion attr to False
+    # Edit consumes selection, set clips selection attr to False
     movemodes.set_range_selection(movemodes.selected_track, 
                                   movemodes.selected_range_in,
                                   movemodes.selected_range_out, 
@@ -553,7 +557,7 @@ def ripple_delete_button_pressed():
     if available_from_range_in < delete_range_length or available_from_range_out < delete_range_length:
         overwrite_track = ripple_data.get_overwrite_data(delete_range_length)
         primary_txt = _("Can't do Ripple Delete!")
-        secondary_txt = _("Seleted Ripple Delete would cause an overwrite and that is not permitted for this edit action.\n\nOverwrite would happen on at track <b>") + utils.get_track_name(overwrite_track, current_sequence()) + "</b>."
+        secondary_txt = _("Selected Ripple Delete would cause an overwrite and that is not permitted for this edit action.\n\nOverwrite would happen on at track <b>") + utils.get_track_name(overwrite_track, current_sequence()) + "</b>."
         parent_window = gui.editor_window.window
         dialogutils.info_message(primary_txt, secondary_txt, parent_window)
         return 
@@ -697,7 +701,7 @@ def range_overwrite_pressed():
         over_clip_out = over_clip.mark_out
         if mark_out_frame == -1:
             # Mark in defined
-            mark_out_frame = mark_in_frame + range_length - 1 # -1 because it gets readded later
+            mark_out_frame = mark_in_frame + range_length - 1 # -1 because it gets read later
         else:
             # Mark out defined
             mark_in_frame = mark_out_frame - range_length + 1
@@ -901,18 +905,24 @@ def sync_all_compositors():
 
 
 # --------------------------------------------------------- view move setting
-def view_mode_menu_lauched(launcher, event):
-    guicomponents.get_monitor_view_popupmenu(launcher, event, _view_mode_menu_item_item_activated)
+def view_mode_menu_lauched(launcher, widget, event):
+    guipopover.monitor_view_popupmenu_show(launcher, widget, _view_mode_menu_item_item_activated, _opacity_menu_item_item_activated)
     
-def _view_mode_menu_item_item_activated(widget, msg):
-    if msg < 3:
-        editorstate.current_sequence().set_output_mode(msg)
-        gui.editor_window.view_mode_select.set_pixbuf(msg)
-    else:
-        mix_value_index = msg - 3 ## this just done in a bit hackish way, 
-        # see guicomponents.get_monitor_view_popupmenu and sequence.SCOPE_MIX_VALUES
-        editorstate.current_sequence().set_scope_overlay_mix(mix_value_index)
+def _view_mode_menu_item_item_activated(action, new_value_variant):
+    msg = int(new_value_variant.get_string())
+    
+    editorstate.current_sequence().set_output_mode(msg)
+    editorstate.tline_view_mode = msg
+    action.set_state(new_value_variant)
+    guipopover._monitorview_popover.hide()
 
+def _opacity_menu_item_item_activated(action, new_value_variant):
+    msg = int(new_value_variant.get_string())
+    mix_value_index = msg - 3 ## this just done in a bit hackish way, 
+    # see guicomponents.get_monitor_view_popupmenu and sequence.SCOPE_MIX_VALUES
+    editorstate.current_sequence().set_scope_overlay_mix(mix_value_index)
+    action.set_state(new_value_variant)
+    guipopover._monitorview_popover.hide()
 
 # ------------------------------------------------------- dialogs    
 def no_monitor_clip_info(parent_window):
@@ -982,15 +992,56 @@ def do_timeline_objects_paste():
         # So that multiple copies with CTRL+V can be made
         new_clips = []
         for clip in paste_clips:
-            if isinstance(clip, int): # blanks, these represented as int's.
+            if isinstance(clip, int): # blanks, these are represented as int's.
                 new_clip = clip 
             else: # media clips
                 new_clip = current_sequence().create_clone_clip(clip)
             new_clips.append(new_clip)
         editorstate.set_copy_paste_objects((COPY_PASTE_DATA_CLIPS, new_clips))
 
-        # Paste clips
-        editevent.do_multiple_clip_insert(track, paste_clips, tline_pos)
+        # Can't put audio media on video track
+        for new_clip in new_clips:
+            if isinstance(new_clip, int):
+                continue
+            if ((new_clip.media_type == appconsts.AUDIO)
+               and (track.type == appconsts.VIDEO)):        
+                _display_no_audio_on_video_msg(track)
+                return
+
+        paste_on_blank = (track.clips[track.get_clip_index_at(tline_pos)].is_blanck_clip == True)
+        paste_on_cut = (current_sequence().get_closest_cut_frame(track.id, tline_pos) == tline_pos)
+        
+        # Paste clips.
+        # Clips are pasted after track content end.
+        if track.get_length() < tline_pos:
+            blank_length = tline_pos - track.get_length() 
+            # Do edit
+            data = {"track":track,
+                    "clips":new_clips,
+                    "blank_length":blank_length}
+            action = edit.insert_multiple_after_end_action(data)
+            action.do_edit()
+        # Clips are pasted on blank.
+        elif paste_on_blank == True and paste_on_cut == False:
+            index = editevent._get_insert_index(track, tline_pos)
+            blank_cut_frame = tline_pos - current_sequence().get_closest_cut_frame(track.id, tline_pos)
+            data = {"track":track,
+                    "clips":new_clips,
+                    "index":index,
+                    "blank_cut_frame":blank_cut_frame}
+            action = edit.insert_multiple_on_blank_action(data)
+            action.do_edit()
+        # Clips are pasted on cut or clip.
+        else:
+            if paste_on_cut == True:
+                editevent.do_multiple_clip_insert(track, paste_clips, tline_pos)
+            else:
+                cut_action = cut_pressed(True)
+                multi_insert_action = editevent.do_multiple_clip_insert(track, paste_clips, tline_pos, True)
+                actions = [cut_action, multi_insert_action]
+                consolidated_action = edit.ConsolidatedEditAction(actions)
+                consolidated_action.do_consolidated_edit()
+                #editevent.do_multiple_clip_insert(track, paste_clips, tline_pos)
     else:
         # Paste clips
         editevent.do_multiple_clip_insert(track, paste_clips, tline_pos)
@@ -1057,10 +1108,10 @@ def _timeline_has_focus(): # copied from keyevents.by. maybe put in utils?
     return False
 
 #------------------------------------------- markers
-def marker_menu_lauch_pressed(widget, event):
-    guicomponents.get_markers_popup_menu(event, _marker_menu_item_activated)
+def marker_menu_lauch_pressed(launcher, widget, event):
+    guipopover.markers_menu_show(launcher, widget, _marker_menu_item_activated)
 
-def _marker_menu_item_activated(widget, msg):
+def _marker_menu_item_activated(action, event, msg):
     current_frame = PLAYER().current_frame()
     mrk_index = -1
     for i in range(0, len(current_sequence().markers)):
