@@ -2,7 +2,7 @@
     Flowblade Movie Editor is a nonlinear video editor.
     Copyright 2012 Janne Liljeblad.
 
-    This file is part of Flowblade Movie Editor <http://code.google.com/p/flowblade>.
+    This file is part of Flowblade Movie Editor <https://github.com/jliljebl/flowblade/>.
 
     Flowblade Movie Editor is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -37,6 +37,7 @@ combo_options = {}
 plugin_groups = {}
 plugin_names = {}
 encoder_groups = {}
+plugin_editor_groups = {}
 
 def init_languages():
     langs = []
@@ -100,7 +101,7 @@ def init_languages():
     # Un-comment for translations tests
     #lang = gettext.translation(APP_NAME, locale_path, languages=["ru"], fallback=True)
 
-    lang.install(APP_NAME) # makes _() a build-in available in all modules without imports
+    lang.install(APP_NAME) # makes _() a built-in available in all modules without imports
 
 def get_filter_name(f_name):
     try:
@@ -223,6 +224,7 @@ def load_filters_translations():
     filter_names["Grain"]= _("Grain")
 
     filter_names["Grayscale"]= _("Grayscale")
+    filter_names["Grayscale Luminance"]= _("Grayscale Luminance")
     filter_names["Contrast"]= _("Contrast")
     filter_names["Saturation"]= _("Saturation")
     filter_names["Invert"]= _("Invert")
@@ -264,10 +266,9 @@ def load_filters_translations():
     filter_names["Shear"]= _("Shear")
     filter_names["Translate"]= _("Translate")
 
-    # 0.8 added
     filter_names["Color Select"]= _("Color Select")
     filter_names["Alpha Modify"]= _("Alpha Modify")
-    filter_names["Spill Supress"]= _("Spill Supress")
+    filter_names["Spill Suppress"]= _("Spill Suppress")
     filter_names["RGB Noise"]= _("RGB Noise")
     filter_names["Box Blur"]= _("Box Blur")
     filter_names["IRR Blur"]= _("IRR Blur")
@@ -322,6 +323,9 @@ def load_filters_translations():
     filter_names["Glitch"] = _("Glitch")
     filter_names["Trails"] = _("Trails")
     filter_names["Blend Mode"] = _("Blend Mode")
+    filter_names["Unpremultiply"] = _("Unpremultiply")
+    filter_names["Fade To Black In / Out"] = _("Fade To Black In / Out")
+    filter_names["Elastic"] = _("Elastic")
     
     # param names
     global param_names
@@ -379,7 +383,7 @@ def load_filters_translations():
     param_names["Roomsize"] = _("Roomsize")
     param_names["Reverb time(s)"] = _("Reverb time(s)")
     param_names["Damping"] = _("Damping")
-    param_names["Input bandwith"] = _("Input bandwith")
+    param_names["Input bandwidth"] = _("Input bandwidth")
     param_names["Dry signal level(dB)"] = _("Dry signal level(dB)")
     param_names["Early reflection level(dB)"] = _("Early reflection level(dB)")
     param_names["Tail level(dB)"] = _("Tail level(dB)")
@@ -515,7 +519,7 @@ def load_filters_translations():
     param_names["R/A/Hue"] = _("R/A/Hue")
     param_names["G/B/Chroma"] = _("G/B/Chroma")
     param_names["B/I/I"] = _("B/I/I")
-    param_names["Supress"] = _("Supress")
+    param_names["Suppress"] = _("Suppress")
     param_names["Horizontal"] = _("Horizontal")
     param_names["Vertical"] = _("Vertical")
     param_names["Type"] = _("Type")
@@ -683,7 +687,17 @@ def load_filters_translations():
     param_names["Reveal Left"] = _("Reveal Left")
     param_names["Reveal Right"] = _("Reveal Right")
     param_names["Fade In Type"] = _("Fade In Type")
-
+    param_names["Image"] = _("Image")
+    param_names["RMP-peak"] = _("RMP-peak")
+    param_names["Relese(ms)"] = _("Relese(ms)")
+    param_names["Ratio"] = _("Ratio")
+    param_names["Knee Radius(dB)"] = _("Knee Radius(dB)")
+    param_names["Makeup gain(dB)"] = _("Makeup gain(dB)")
+    param_names["Velocity"] = _("Velocity")
+    param_names["Center"] = _("Center")
+    param_names["Width"] = _("Width")
+    param_names["Linear Scale"] = _("Linear Scale")
+    param_names["Non-Linear Scale"] = _("Non-Linear Scale")
 
     # Combo options
     global combo_options
@@ -823,15 +837,27 @@ def load_filters_translations():
     combo_options["Underline"] = _("Underline")
     combo_options["Strikethrought"] = _("Strikethrought")
     combo_options["Lines Solid"] = _("Lines Solid")
-
+    combo_options["Diagonal"] = _("Diagonal")
+    combo_options["XDiagonal"] = _("XDiagonal")
+    combo_options["Left"] = _("Left")
+    combo_options["Right"] = _("Right")
+    
     # Added for 2.10
+    global plugin_groups
     plugin_groups["Backgrounds"] = _("Backgrounds")
     plugin_groups["Cover Transitions"] = _("Cover Transitions")
     plugin_groups["Animated Texts"] = _("Animated Texts")
     
+    global plugin_names
     plugin_names["Lines Sweep"] = _("Lines Sweep")
     plugin_names["Hex Colors"] = _("Hex Colors")
     plugin_names["Floating Boxes"] = _("Floating Boxes")
     plugin_names["Typewriter"] = _("Typewriter")
     plugin_names["Multiline Text"] = _("Multiline Text")
     plugin_names["Hex Overlay"] = _("Hex Overlay")
+
+    global plugin_editor_groups
+    plugin_editor_groups["Text"] = _("Text")
+    plugin_editor_groups["Animation"] = _("Animation")
+    plugin_editor_groups["Background"] = _("Background")
+
